@@ -19,13 +19,12 @@ This crate provides the following utilities:
     unused_qualifications
 )]
 
-use extension_trait::extension_trait;
 use std::{
     fmt::{Debug, Formatter, Result},
     iter::repeat_with,
     ops::Deref,
 };
-use trillium::{async_trait, Conn, Handler, HeaderName, KnownHeaderName};
+use trillium::{async_trait, Conn, Handler, HeaderName, KnownHeaderName, StateSet};
 
 /**
 Trillium handler to set a identifier for every Conn.
@@ -247,13 +246,20 @@ impl Handler for ConnId {
 }
 
 /// Extension trait to retrieve an id generated by the [`ConnId`] handler
-#[extension_trait]
-pub impl ConnIdExt for Conn {
+pub trait ConnIdExt {
     /// Retrieves the id for this conn. This method will panic if it
     /// is run before the [`ConnId`] handler.
+    fn id(&self) -> &str;
+}
+
+impl<ConnLike> ConnIdExt for ConnLike
+where
+    ConnLike: AsRef<StateSet>,
+{
     fn id(&self) -> &str {
         &*self
-            .state::<Id>()
+            .as_ref()
+            .get::<Id>()
             .expect("ConnId handler must be run before calling IdConnExt::id")
     }
 }
@@ -271,3 +277,8 @@ pub mod log_formatter {
             .unwrap_or_else(|| Cow::Borrowed("-"))
     }
 }
+
+/// Alias for ConnId::new()
+pub fn conn_id() -> ConnId {
+    ConnId::new()
+}
